#region Copyright  2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Core.Interface
{
    using System.Collections.Generic;
    using System.Net.Mail;

    /// <summary>
    /// Interface defining how the <see cref="IExecptionHandler"/> implementation
    /// sends exception email. Since this is for exception handling, the implementor
    /// should define the 'To' email address.
    /// </summary>
    public interface ISendExceptionEmail
    {

        /// <summary>
        /// Gets the email attachments.
        /// </summary>
        /// <value>The email attachments.</value>
        List<Attachment> Attachments { get; }

        /// <summary>
        /// Gets or sets the body of the email.
        /// </summary>
        /// <value>The body of the email.</value>
        string Body { get; set; }

        /// <summary>
        /// Gets or sets 'From' email address.
        /// </summary>
        /// <value>The 'From' email address.</value>
        string FromEmailAddress { get; set; }

        /// <summary>
        /// Gets or sets the email subject line.
        /// </summary>
        /// <value>The email subject line.</value>
        string Subject { get; set; }


        /// <summary>
        /// Determines whether this instance can send email with the current properties.
        /// </summary>
        /// <returns>
        /// 	<c>true</c> if this instance can send email; otherwise, <c>false</c>.
        /// </returns>
        bool CanSendEmail();

        /// <summary>
        /// Sends the email with the current property values.
        /// </summary>
        /// <param name="errorMessage">An error message about why the email could not be sent.</param>
        /// <returns>
        /// 	<c>true</c> if the email could be sent; otherwise, <c>false</c>.
        /// </returns>
        bool SendEmail(out string errorMessage);
    }
}
