#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion


namespace DevExpressContrib.Core.Ux
{
    using System;
    using System.Drawing;
    using System.Windows.Forms;
    using DevExpressContrib.Core.Interface;

    /// <summary>
    /// Simple class to process unhandled exceptions. Uses ThreadExceptionDialog
    /// to display the exception information.
    /// </summary>
    public class SimpleExceptionHandler : ExceptionHandlerBase, IExecptionHandler
    {

        /// <summary>
        /// Initializes a new instance of the <see cref="T:DevExpressContrib.Core.ExceptionHandlerBase">ExceptionHandlerBase</see> class. 
        /// </summary>
        public SimpleExceptionHandler(IServicesHelper servicesHelper) : base(servicesHelper) { }

        /// <summary>
        /// Shows the specified exception.
        /// </summary>
        /// <param name="exception">The exception.</param>
        /// <param name="args">Information about the exception.</param>
        /// <returns>
        /// DialogResult of the dialog showing the exception details.
        /// </returns>
        public override DialogResult Show(Exception exception, ExceptionHandlerArgs args)
        {
            DialogResult result;
            GetServicesHelper().LogException("Unhandled Exception", exception);
            using (ThreadExceptionDialog dialog = new ThreadExceptionDialog(exception))
            {
                SetDefaultExceptionHandlerValues(args);
                dialog.Text = args.Caption;
                result = dialog.ShowDialog();
                if (CanSendEmail())
                {
                    DialogResult emailResult = MessageBox.Show(GetServicesHelper().GetString("SimpleExceptionHandlerEmailQuestionText"),
                        GetServicesHelper().GetString("SimpleExceptionHandlerEmailQuestionCaption"), MessageBoxButtons.YesNoCancel,
                        MessageBoxIcon.Question);
                    if (emailResult == DialogResult.Yes || emailResult == DialogResult.No)
                    {
                        string fromEmailAddress = ReadFromEmailAddress();
                        if (emailResult == DialogResult.Yes)
                            using (Image screenshot = GetScreenshot())
                                SendEmail(exception, fromEmailAddress, true, screenshot);
                        else
                            SendEmail(exception, fromEmailAddress, false, null);
                    }
                }
                if (result == DialogResult.Abort || args.IsFatal)
                {
                    GetServicesHelper().LogFatal("Exiting Application.");
                    Environment.Exit(args.ExitCode);
                }
            }
            return result;
        }
    }
}
