#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Core.Ux
{
    using System;
    using System.Drawing;
    using DevExpress.XtraEditors;

    /// <summary>
    /// Class to hold the watermark input prompt information.
    /// </summary>
    [ObsoleteAttribute("WatermarkInputPromptItem is no longer necessary. Use Properties.NullValuePrompt instead.", false)]
    public class WatermarkInputPromptItem
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="WatermarkInputPromptItem"/> class.
        /// </summary>
        /// <param name="editControl">The edit control.</param>
        /// <param name="prompt">The prompt.</param>
        /// <param name="passwordChar">The password character. If this is set then
        /// a TextEdit control will hide the content of the control.</param>
        /// <param name="watermarkTextColor">Color of the watermark text.</param>
        /// <param name="textColor">Color of the text.</param>
        public WatermarkInputPromptItem(BaseEdit editControl, string prompt,
            char passwordChar, Color watermarkTextColor, Color textColor)
        {
            GuardAgainst.ArgumentIsNotTypeOf(editControl, typeof(BaseEdit), "editControl");
            EditControl = editControl;
            Prompt = prompt;
            WatermarkTextColor = watermarkTextColor;
            TextColor = textColor;
            PasswordChar = passwordChar;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="WatermarkInputPromptItem"/> class.
        /// Colors are set to the default colors.
        /// </summary>
        /// <param name="editControl">The edit control.</param>
        /// <param name="prompt">The prompt.</param>
        /// <param name="passwordChar">The password character. If this is set then
        /// a TextEdit control will hide the content of the control.</param>
        public WatermarkInputPromptItem(BaseEdit editControl, string prompt, char passwordChar)
            : this(editControl, prompt, passwordChar, Color.Empty, Color.Empty) { }

        /// <summary>
        /// Initializes a new instance of the <see cref="WatermarkInputPromptItem"/> class.
        /// Colors are set to the default colors.
        /// </summary>
        /// <param name="editControl">The edit control.</param>
        /// <param name="prompt">The prompt.</param>
        public WatermarkInputPromptItem(BaseEdit editControl, string prompt)
            : this(editControl, prompt, default(char)) { }

        /// <summary>
        /// Gets or sets the edit control.
        /// </summary>
        /// <value>The edit control.</value>
        public BaseEdit EditControl { get; set; }

        /// <summary>
        /// Gets or sets the password character.
        /// </summary>
        /// <value>The password character.</value>
        public char PasswordChar { get; set; }

        /// <summary>
        /// Gets or sets the watermark prompt.
        /// </summary>
        /// <value>The watermark prompt.</value>
        public string Prompt { get; set; }

        /// <summary>
        /// Gets or sets the color of the text.
        /// </summary>
        /// <value>The color of the text.</value>
        public Color TextColor { get; set; }

        /// <summary>
        /// Gets or sets the color of the watermark text.
        /// </summary>
        /// <value>The color of the watermark text.</value>
        public Color WatermarkTextColor { get; set; }
    }
}
