#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Core
{
    using System;
    using System.Windows.Forms;
    using DevExpress.XtraEditors.DXErrorProvider;
    using DevExpressContrib.Core.Interface;

    /// <summary>
    /// Validation rule for well-formed email address.
    /// </summary>
    public class EmailValidationRule : ValidationRule
    {

        private IServicesHelper servicesHelper;


        /// <summary>
        /// Initializes a new instance of the <see cref="EmailValidationRule"/> class.
        /// </summary>
        /// <param name="name">The name.</param>
        /// <param name="servicesHelper">The services helper.</param>
        public EmailValidationRule(string name, IServicesHelper servicesHelper)
            : base(name)
        {
            this.servicesHelper = servicesHelper;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="EmailValidationRule"/> class.
        /// </summary>
        /// <param name="servicesHelper">The services helper.</param>
        public EmailValidationRule(IServicesHelper servicesHelper) : this(String.Empty, servicesHelper) { }


        /// <summary>
        /// Validates the specified control.
        /// </summary>
        /// <param name="control">The control.</param>
        /// <param name="value">The value.</param>
        /// <returns><c>true</c> if the control was valid; otherwise <c>false</c>.</returns>
        public override bool Validate(Control control, object value)
        {
            if (value == null || value.ToString().Trim() == String.Empty)
                return true;
            if (!EmailHelper.IsEmailAddressWellFormed(value.ToString()))
            {
                ErrorText = servicesHelper.GetString("MalformedEmailAddress");
                ErrorType = ErrorType.Critical;
                return false;
            }
            else
                return true;
        }
    }
}
