#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Core
{
    using System;
    using System.Windows.Forms;
    using DevExpressContrib.Core.Interface;

    /// <summary>
    /// Implementation of IExceptionHandler using the console to display the exception.
    /// Does not use the 'what happened', 'how affected' or 'what to do' text.
    /// </summary>
    public class ConsoleExceptionHandler : ExceptionHandlerBase, IExecptionHandler
    {

        /// <summary>
        /// Initializes a new instance of the <see cref="T:DevExpressContrib.Core.ExceptionHandlerBase">ExceptionHandlerBase</see> class. 
        /// </summary>
        public ConsoleExceptionHandler(IServicesHelper servicesHelper) : base(servicesHelper) { }


        /// <summary>
        /// Gets a value indicating whether this handler supports emailing the exception back to your company.
        /// </summary>
        /// <value><c>true</c> if email is supported; otherwise, <c>false</c>.</value>
        public override bool SupportsEmail { get { return false; } }


        /// <summary>
        /// Shows the specified exception.
        /// </summary>
        /// <param name="exception">The exception.</param>
        /// <param name="args">Information about the exception.</param>
        /// <returns>
        /// DialogResult of the dialog showing the exception details.
        /// </returns>
        public override DialogResult Show(Exception exception, ExceptionHandlerArgs args)
        {
            GetServicesHelper().LogException("Unhandled Exception", exception);
            SetDefaultExceptionHandlerValues(args);
            Console.Write(ExceptionDetails(exception));
            if (args.IsFatal)
            {
                Environment.Exit(args.ExitCode);
                return DialogResult.Abort;
            }
            return DialogResult.OK;
        }
    }
}
