#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Core
{
    using System;
    using System.Reflection;
    using System.Resources;

    /// <summary>
    /// ResourceHelper contains methods to obtain the ResourceManager for the
    /// standard resource file of an assembly.
    /// </summary>
    public static class ResourceHelper
    {

        /// <summary>
        /// Gets the assembly resource manager for the supplied assembly.
        /// </summary>
        /// <param name="assembly">The supplied assembly.</param>
        /// <returns>The ResourceManager of the supplied assembly.</returns>
        public static ResourceManager GetAssemblyResourceManager(Assembly assembly)
        {
            Type resourceType = GetAssemblyResourceType(assembly);
            if (resourceType != null)
                return new ResourceManager(resourceType);
            return null;
        }

        /// <summary>
        /// Gets the type of the supplied assembly resource.
        /// </summary>
        /// <param name="assembly">The assembly.</param>
        /// <returns>The type of the resource file.</returns>
        public static Type GetAssemblyResourceType(Assembly assembly)
        {
            foreach (Type type in assembly.GetTypes())
                if (type.FullName.EndsWith("Properties.Resources"))
                    return type;
            return null;
        }
    }
}
