#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchema.Interface
{
    using System;

    /// <summary>
    /// Decorates a persistent property or field that <see cref="UpdateSchema"/> will rename.
    /// The old column name is passed into the attribute. The new column name will be
    /// derived from the property/field name or the MapTo attribute.
    /// </summary>
    [AttributeUsage(AttributeTargets.Field | AttributeTargets.Property, Inherited = true, AllowMultiple = true)]
    public class RenameColumnAttribute : Attribute
    {

        /// <summary>
        /// Initializes a new instance of the <see cref="RenameColumnAttribute"/> class.
        /// </summary>
        /// <param name="oldColumnName">Old name of the column.</param>
        public RenameColumnAttribute(string oldColumnName)
        {
            OldColumnName = oldColumnName;
            IgnoreConditions = UpdateSchemaIgnoreConditions.None;
        }


        /// <summary>
        /// Gets or sets a value indicating which conditions the update should ignore
        /// when updating the schema.
        /// </summary>
        /// <value>Conditions to ignore when attempting the update.</value>
        public UpdateSchemaIgnoreConditions IgnoreConditions { get; set; }

        /// <summary>
        /// Gets or sets the old name of the column.
        /// </summary>
        /// <value>The old name of the column.</value>
        public string OldColumnName { get; set; }
    }
}
