#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchema.Interface
{
    using DevExpress.Xpo;

    /// <summary>
    /// ISchemaVersion defines how a class implements updating a data store schema version.
    /// </summary>
    public interface ISchemaVersion
    {

        /// <summary>
        /// Gets or sets the connection string.
        /// </summary>
        /// <value>The connection string.</value>
        string ConnectionString { get; set; }

        /// <summary>
        /// Gets the current schema version from the data store.
        /// </summary>
        /// <value>The value (as an object) of the current data store schema version.
        /// Returns null of the schema version does not exist.</value>
        object CurrentSchemaVersion { get; }

        /// <summary>
        /// Gets or sets the XPO data layer use to access the data store.
        /// </summary>
        /// <value>The data layer.</value>
        IDataLayer DataLayer { get; set; }

        /// <summary>
        /// Determines whether the schema version has been updated to the
        /// <see cref="RequiredSchemaVersion"/> current. Uses the
        /// <see cref="CurrentSchemaVersion"/> as the value to check against.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if the <see cref="CurrentSchemaVersion"/> value in the 
        /// 	data store is equal to the <see cref="RequiredSchemaVersion"/>; otherwise, <c>false</c>.
        /// </value>
        bool HasSchemaVersionBeenUpdated { get; }

        /// <summary>
        /// Gets the required schema version (as an object). This value is what
        /// the schema version should be for the current version of the application.
        /// </summary>
        /// <value>
        /// The value (as an object) of the required data source schema version.
        /// </value>
        object RequiredSchemaVersion { get; }


        /// <summary>
        /// Updates the <see cref="CurrentSchemaVersion"/> to the <see cref="RequiredSchemaVersion"/>.
        /// </summary>
        /// <returns>
        /// 	<c>true</c> if the version was updated; otherwise <f>false</f>.
        /// </returns>
        bool UpdateSchemaVersion();
    }
}
