#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchema.Interface
{
    using System;

    /// <summary>
    /// Define the update schema conditions to ignore when performing the update.
    /// </summary>
    [Flags]
    public enum UpdateSchemaIgnoreConditions
    {
        /// <summary>
        /// Don't attempt the update if there are conditions on the column or table.
        /// </summary>
        None = 0,

        /// <summary>
        /// Attempt the update even if there is a foreign key constraint on the column.
        /// </summary>
        ForeignKey = 1,

        /// <summary>
        /// Attempt the update even if there is an index constraint on the column.
        /// </summary>
        Index = 2,

        /// <summary>
        /// Attempt the update even if there are string values that will be truncated.
        /// </summary>
        TruncateString = 4,

        /// <summary>
        /// Ignore everything - attempt the update regardless of the conditions.
        /// </summary>
        All = ForeignKey | Index | TruncateString
    }

    /// <summary>
    /// Helper class for the UpdateSchemaType enumeration
    /// </summary>
    public static class UpdateSchemaIgnoreConditionsHelper
    {

        /// <summary>
        /// Determines whether the or'ed list of UpdateSchemaIgnoreConditions contains the supplied type.
        /// </summary>
        /// <param name="list">The list.</param>
        /// <param name="type">The type.</param>
        /// <returns>
        /// 	<c>true</c> if type is contained in the list; otherwise, <c>false</c>.
        /// </returns>
        public static bool ContainsIgnoreCondition(UpdateSchemaIgnoreConditions list, UpdateSchemaIgnoreConditions type)
        {
            return (list & type) == type;
        }
    }
}
