#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchema.Interface
{
    using System;
    using DevExpress.Xpo.Metadata;

    /// <summary>
    /// Levels of logging messages for the UpdateSchema.
    /// </summary>
    public enum UpdateSchemaLogLevel
    {
        /// <summary>
        /// Whatever the heck happened here, the UpdateSchema is now in an unstable 
        /// state and should be terminated.
        /// </summary>
        Fatal = 4,

        /// <summary>
        /// There was a major problem but the UpdateSchema is still in a stable state.
        /// </summary>
        Error = 3,

        /// <summary>
        /// There was some minor problem which should be logged.
        /// </summary>
        Warning = 2,

        /// <summary>
        /// Some interesting information.
        /// </summary>
        Information = 1
    }

    /// <summary>
    /// Converter to store the UpdateSchemaLogLevel into the XPO data store.
    /// </summary>
    public class UpdateSchemaLogLevelConverter : ValueConverter
    {

        /// <summary>
        /// When overridden in a derived class, gets the type that the property's value is converted to when it's saved in a data store.
        /// </summary>
        /// <value>
        /// A <see cref="T:System.Type"/> descendant which represents the type that the property's value is converted to when it's saved in a data store.
        /// </value>
        public override Type StorageType
        {
            get { return typeof(string); }
        }


        /// <summary>
        /// When overridden in a derived class, converts the value which is stored in a data store to the persistent property's value.
        /// </summary>
        /// <param name="value">An object which represents the UpdateSchemaLogLevel to convert.</param>
        /// <returns>
        /// An object which represents the converted value.
        /// </returns>
        public override object ConvertFromStorageType(object value)
        {
            return (UpdateSchemaLogLevel)Enum.Parse(typeof(UpdateSchemaLogLevel), value as string, true);
        }

        /// <summary>
        /// When overridden in a derived class, converts the persistent property's value to the value which is stored in a data store.
        /// </summary>
        /// <param name="value">An object which represents the UpdateSchemaLogLevel to convert.</param>
        /// <returns>
        /// An object which represents the converted value.
        /// </returns>
        public override object ConvertToStorageType(object value)
        {
            return value.ToString();
        }
    }
}
