#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchema
{
    using System;
    using System.Collections.Generic;
    using System.Reflection;
    using DevExpress.Xpo;

    /// <summary>
    /// Helper class for the <see cref="UpdateSchema"/> class.
    /// </summary>
    public static class UpdateSchemaHelper
    {

        /// <summary>
        /// Gets a list of all table names within the supplied assemblies. Information
        /// is found via assembly meta-data.
        /// </summary>
        /// <param name="assemblies">The assemblies.</param>
        /// <returns>List&lt;string&gt; of table names.</returns>
        public static List<string> TableNames(Assembly[] assemblies)
        {
            List<string> tableNames = new List<string>();
            foreach (Assembly assembly in assemblies)
            {
                Type[] types = assembly.GetTypes();
                foreach (Type type in types)
                    if (type.IsSubclassOf(typeof(XPBaseObject)))
                    {
                        string tableName = UpdateItemManager.GetTableName(type);
                        if (!String.IsNullOrEmpty(tableName))
                            tableNames.Add(tableName);
                    }
            }
            return tableNames;
        }
    }
}
