#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchema
{
    using System;

    // UpdateSchemaProviderAttribute =============================================================================
    /// <summary>
    /// Decorates an XPO update schema provider. This attribute is required on
    /// all update providers.
    /// </summary>
    [AttributeUsage(AttributeTargets.Class, Inherited = false)]
    public class UpdateSchemaProviderAttribute : Attribute
    {

        /// <summary>
        /// Initializes a new instance of the <see cref="UpdateSchemaProviderAttribute"/> class.
        /// </summary>
        /// <param name="xpoProviderTypeString">The XPO provider type string.</param>
        public UpdateSchemaProviderAttribute(string xpoProviderTypeString)
        {
            XpoProviderTypeString = xpoProviderTypeString;
        }


        /// <summary>
        /// Gets or sets the XPO provider type string.
        /// </summary>
        /// <value>The XPO provider type string.</value>
        public string XpoProviderTypeString { get; set; }
    }
}
