#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchema
{
    using DevExpressContrib.Core.Interface;
    using DevExpressContrib.Xpo.UpdateSchema.Interface;

    /// <summary>
    /// Implements a small set of core members for update schema providers.
    /// </summary>
    public class BaseUpdateSchemaProvider
    {

        /// <summary>
        /// The default list of supported update schema types. This includes all
        /// possible updates.
        /// </summary>
        protected UpdateSchemaType DefaultSupportedUpdateSchemaTypes =
            UpdateSchemaType.ShrinkColumnStringLength
            | UpdateSchemaType.GrowColumnStringLength
            | UpdateSchemaType.RenameColumn
            | UpdateSchemaType.DeleteColumn;


        /// <summary>
        /// Initializes a new instance of the <see cref="BaseUpdateSchemaProvider"/> class.
        /// </summary>
        /// <param name="servicesHelper">The services helper.</param>
        public BaseUpdateSchemaProvider(IServicesHelper servicesHelper)
        {
            ServicesHelper = servicesHelper;
        }


        /// <summary>
        /// Gets the connection string.
        /// </summary>
        /// <value>The connection string.</value>
        public string ConnectionString { get; protected set; }

        /// <summary>
        /// Gets or sets the services helper.
        /// </summary>
        /// <value>The services helper.</value>
        protected IServicesHelper ServicesHelper { get; set; }

        /// <summary>
        /// Gets or sets the update schema information logger.
        /// </summary>
        /// <value>The logger.</value>
        public UpdateSchemaLogger UpdateSchemaLogger { get; set; }


        /// <summary>
        /// Determine whether the provider supports the supplied type of schema update.
        /// </summary>
        /// <param name="updateSchemaType">Type of update schema.</param>
        /// <returns>
        /// 	<c>true</c> if the provider supports the supplied type of schema update; otherwise <c>false</c>.
        /// </returns>
        public virtual bool SupportsUpdateSchemaType(UpdateSchemaType updateSchemaType)
        {
            return UpdateSchemaTypeHelper.ContainsUpdateSchemaType(DefaultSupportedUpdateSchemaTypes, updateSchemaType);
        }
    }
}
