#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchema
{
    using System;

    /// <summary>
    /// The types of schema updates that the DevExpressContrib.Xpo.UpdateSchema provides.
    /// </summary>
    [Flags]
    public enum UpdateSchemaType
    {
        /// <summary>
        /// Reduce the size of a string column.
        /// </summary>
        ShrinkColumnStringLength = 0,

        /// <summary>
        /// Expand the size of a string column.
        /// </summary>
        GrowColumnStringLength = 1,

        /// <summary>
        /// Rename a column within a table.
        /// </summary>
        RenameColumn = 2,

        /// <summary>
        /// Delete a column within a table.
        /// </summary>
        DeleteColumn = 4
    }

    /// <summary>
    /// Helper class for the UpdateSchemaType enumeration
    /// </summary>
    public static class UpdateSchemaTypeHelper
    {

        /// <summary>
        /// Determines whether the or'ed list of UpdateSchemeType contains the supplied type.
        /// </summary>
        /// <param name="list">The list.</param>
        /// <param name="type">The type.</param>
        /// <returns>
        /// 	<c>true</c> if type is contained in the list; otherwise, <c>false</c>.
        /// </returns>
        public static bool ContainsUpdateSchemaType(UpdateSchemaType list, UpdateSchemaType type)
        {
            return (list & type) == type;
        }
    }
}
