#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchemaReports
{
    using System;
    using System.Collections;
    using DevExpress.XtraReports.UI;
    using DevExpressContrib.Xpo.UpdateSchema.Interface;

    /// <summary>
    /// The XtraReports report class.
    /// </summary>
    public partial class UpdateSchemaLogReport : XtraReport
    {

        /// <summary>
        /// Initializes a new instance of the <see cref="UpdateSchemaLogReport"/> class.
        /// </summary>
        /// <param name="reportData">The report data.</param>
        public UpdateSchemaLogReport(IList reportData)
        {
            InitializeComponent();
            DataSource = reportData;
            InitializeReportDataBinding();
        }


        private void Detail_BeforePrint(object sender, System.Drawing.Printing.PrintEventArgs e)
        {
            Detail.StyleName = "styleNormal";
            object currentRow = GetCurrentRow();
            if (currentRow is UpdateSchemaLogEntry)
            {
                UpdateSchemaLogEntry row = currentRow as UpdateSchemaLogEntry;
                int extraBandHeight = messageDetail.Top;
                exceptionDetail.Visible = !String.IsNullOrEmpty(row.ExceptionText);
                int height;
                if (exceptionDetail.Visible)
                    height = exceptionDetail.Top + exceptionDetail.Height + extraBandHeight;
                else
                    height = messageDetail.Top + messageDetail.Height + extraBandHeight;
                Detail.Height = height;
                if (row.UpdateSchemaLogLevel >= UpdateSchemaLogLevel.Error)
                {
                    Detail.StyleName = "styleError";
                }
            }
        }

        private void InitializeReportDataBinding()
        {
            dateTimeDetail.DataBindings.Add(new XRBinding("Text", DataSource, "LogTime"));
            severityDetail.DataBindings.Add(new XRBinding("Text", DataSource, "LogLevel"));
            messageDetail.DataBindings.Add(new XRBinding("Text", DataSource, "Message"));
            exceptionDetail.DataBindings.Add(new XRBinding("Text", DataSource, "FullException"));
        }
    }
}
