#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.Xpo.UpdateSchemaReports
{
    using System.Linq;
    using DevExpress.Xpo;
    using DevExpressContrib.Core;
    using DevExpressContrib.Xpo.UpdateSchema.Interface;

    /// <summary>
    /// Report showing UpdateSchema results and information.
    /// </summary>
    public class UpdateSchemaReports
    {

        private IDataLayer dataLayer;


        /// <summary>
        /// Initializes a new instance of the <see cref="UpdateSchemaReports"/> class.
        /// </summary>
        /// <param name="dataLayer">The data layer.</param>
        public UpdateSchemaReports(IDataLayer dataLayer)
        {
            GuardAgainst.ArgumentIsNull(dataLayer, "dataLayer");

            this.dataLayer = dataLayer;
        }


        /// <summary>
        /// Generates the log report to a PDF file.
        /// </summary>
        /// <param name="fileName">Name of the PDF file.</param>
        public void GenerateLogReportToPdf(string fileName)
        {
            GuardAgainst.ArgumentIsNull(fileName, "fileName");
            GuardAgainst.ArgumentIsNullOrEmpty(fileName.Trim(), "fileName");

            using (Session session = new Session(dataLayer, null))
            {
                XPQuery<UpdateSchemaLogEntry> entryData = new XPQuery<UpdateSchemaLogEntry>(session);
                var reportData = from entries in entryData orderby entries.Counter select entries;
                using (UpdateSchemaLogReport report = new UpdateSchemaLogReport(reportData.ToList()))
                    report.ExportToPdf(fileName);
            }
        }
    }
}
