#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace DevExpressContrib.XtraGrid.DxValidateColumnProvider
{
    using DevExpress.XtraEditors.DXErrorProvider;
    using DevExpress.XtraGrid.Columns;
    using DevExpress.XtraGrid.Views.Base;

    /// <summary>
    /// Interface for column and row validators. All column and row validators must
    /// implement this interface.
    /// </summary>
    public interface IColumnValidator
    {

        /// <summary>
        /// Gets or sets the column to validate.
        /// </summary>
        /// <value>The column.</value>
        GridColumn Column { get; set; }

        /// <summary>
        /// Gets or sets the default error text. If this is String.Empty or null
        /// the system will set generic error text.
        /// </summary>
        /// <value>The default error text.</value>
        string DefaultErrorText { get; set; }

        /// <summary>
        /// Gets or sets the error text.
        /// </summary>
        /// <value>The error text.</value>
        string ErrorText { get; set; }

        /// <summary>
        /// Gets or sets the type of the error icon that is shown.
        /// </summary>
        /// <value>The type of the error.</value>
        ErrorType ErrorType { get; set; }

        /// <summary>
        /// Gets or sets the row handle of the current row in the view.
        /// </summary>
        /// <value>The row handle.</value>
        int RowHandle { get; set; }

        /// <summary>
        /// Gets or sets the view to which the column belongs.
        /// </summary>
        /// <value>The view.</value>
        BaseView View { get; set; }


        /// <summary>
        /// Determines whether this instance can be validated.
        /// </summary>
        /// <returns>
        /// 	<c>true</c> if this instance can be validated; otherwise, <c>false</c>.
        /// </returns>
        bool CanValidate();

        /// <summary>
        /// Validates the specified value.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <returns><c>true</c> if the value (or values) are valid; otherwise <c>false</c>.</returns>
        bool Validate(object value);
    }
}
