﻿#region Copyright © 2009, DevExcpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace Test.Ux.ExceptionHandler
{
    using System;
    using System.Text;
    using System.Windows.Forms;
    using DevExpressContrib.Core;
    using DevExpressContrib.Core.Interface;

    public class ExceptionHandlerUserDefined : IExceptionHandlerUserDefined
    {

        private IServicesHelper servicesHelper;
        private UserDefinedUserControl userControl = null;


        public string Data
        {
            get { return GetData(); }
        }

        public string TabText
        {
            get { return "More Info"; }
        }

        public UserControl UserInterface
        {
            get 
            {
                if (userControl == null)
                    userControl = new UserDefinedUserControl();
                return userControl;
            }
        }

        public void FinalizeUI()
        {
            if (userControl == null)
                return;
            GetServicesHelper().WriteConfigString("ExceptionHandlerCallName", userControl.nameText.Text);
            GetServicesHelper().WriteConfigString("ExceptionHandlerPhoneNumber", userControl.phoneNumberText.Text);
            userControl = null;
        }

        public void InitializeUI()
        {
            if (userControl == null)
                return;
            userControl.nameText.Text = GetServicesHelper().ReadConfigString("ExceptionHandlerCallName");
            userControl.phoneNumberText.Text = GetServicesHelper().ReadConfigString("ExceptionHandlerPhoneNumber");
        }

        private string GetData()
        {
            if (userControl == null)
                return String.Empty;

            StringBuilder data = new StringBuilder();
            if (userControl.callCheckEdit.Checked)
            {
                data.AppendFormat("Person to call: {0}", userControl.nameText.Text);
                data.AppendLine();
                data.AppendFormat("Phone number: {0}", userControl.phoneNumberText.Text);
                data.AppendLine();
            }
            data.AppendFormat("Serial #: {0}", userControl.serialNumberLabel.Text);
            data.AppendLine();
            data.AppendLine();
            data.AppendFormat("Log Messages: {0}{1}", Environment.NewLine, userControl.logMessagesMemo.Text);
            return data.ToString();
        }

        private IServicesHelper GetServicesHelper()
        {
            if (servicesHelper == null)
                servicesHelper = new DefaultServicesHelper();
            return servicesHelper;
        }
    }
}
