#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace Test.Ux.WatermarkInputPrompt
{
    using System.Drawing;
    using DevExpress.XtraEditors.DXErrorProvider;
    using DevExpressContrib.Core.Ux;

    public partial class TestForm : DevExpress.XtraEditors.XtraForm
    {

        private const char passwordCharacter = (char)0x25CF;
        private WatermarkInputPromptManager watermarkManager;


        public TestForm()
        {
            InitializeComponent();
            xtraTabControl.SelectedTabPageIndex = 0;

            watermarkManager = new WatermarkInputPromptManager(Color.Plum, Color.Empty);

            // use the default prompt
            watermarkManager.Add(textEdit);
            // the password character can be passed into the watermark manager
            watermarkManager.Add(password, passwordCharacter);
            watermarkManager.Add(passwordWithInitialText, passwordCharacter);
            watermarkManager.Add(buttonEdit);
            watermarkManager.Add(comboBoxEdit);
            watermarkManager.Add(dateEdit);
            watermarkManager.Add(mruEdit);
            watermarkManager.Add(memoEdit);
            watermarkManager.Add(calcEdit);

            // use custom prompts for each editor
            watermarkManager.Add(layoutTextEdit, "Empty TextEdit");
            // the password character can be read from the TextEdit properties
            layoutPassword.Properties.PasswordChar = passwordCharacter;
            watermarkManager.Add(layoutPassword, "Empty Password");
            watermarkManager.Add(layoutButtonEdit, "Empty ButtonEdit");
            watermarkManager.Add(layoutComboBoxEdit, "Empty comboBoxEdit");
            watermarkManager.Add(layoutDateEdit, "Empty DateEdit");
            watermarkManager.Add(layoutMruEdit, "Empty MRUEdit");
            watermarkManager.Add(layoutMemoEdit, "Empty MemoEdit");
            watermarkManager.Add(layoutCalcEdit, "Empty CalcEdit");

            watermarkManager.Add(validateTextEdit);
            watermarkManager.Add(validatePassword, passwordCharacter);
            watermarkManager.Add(validateButtonEdit);
            watermarkManager.Add(validateComboBoxEdit);
            watermarkManager.Add(validateDateEdit);
            watermarkManager.Add(validateMruEdit);
            watermarkManager.Add(validateMemoEdit);
            watermarkManager.Add(validateCalcEdit);

            watermarkManager.AllowWatermarksWithDxValidationProviderKludge = true;
            ConditionValidationRule rule = new ConditionValidationRule("Not Blank", ConditionOperator.IsNotBlank);
            dxValidationProvider.SetValidationRule(validateTextEdit, rule);
            dxValidationProvider.SetValidationRule(validatePassword, rule);
            dxValidationProvider.SetValidationRule(validateButtonEdit, rule);
            dxValidationProvider.SetValidationRule(validateComboBoxEdit, rule);
            dxValidationProvider.SetValidationRule(validateDateEdit, rule);
            dxValidationProvider.SetValidationRule(validateMruEdit, rule);
            dxValidationProvider.SetValidationRule(validateMemoEdit, rule);
            dxValidationProvider.SetValidationRule(validateCalcEdit, rule);

            passwordWithInitialText.Text = "Password01";
        }


        private void allowKludgeCheckEdit_CheckedChanged(object sender, System.EventArgs e)
        {
            watermarkManager.AllowWatermarksWithDxValidationProviderKludge = allowKludgeCheckEdit.Checked;
        }

        private void closeButton_Click(object sender, System.EventArgs e)
        {
            watermarkManager.Dispose();
            Close();
        }
    }
}