#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace Test.Xpo.UpdateSchema
{
    using System;
    using System.Collections.Generic;
    using System.Reflection;
    using DevExpress.Xpo;
    using DevExpress.Xpo.DB;
    using DevExpressContrib.Xpo.UpdateSchema;
    using NUnit.Framework;
    using NUnit.Framework.SyntaxHelpers;

    internal static class TestHelper
    {

        internal static bool DropDatabase(Type type, string connectionString)
        {
            MethodInfo methodInfo = type.GetMethod("DropDatabase", BindingFlags.FlattenHierarchy | BindingFlags.Static | BindingFlags.Public);
            if (methodInfo != null)
                return (bool)methodInfo.Invoke(null, new object[] { connectionString });
            return false;
        }

        internal static Type GetProviderType(string connectionString)
        {
            Dictionary<string, Type> availableProviders = new Dictionary<string, Type>();
            List<Assembly> additionalAssemblies = new List<Assembly>();
            additionalAssemblies.Add(Assembly.GetAssembly(typeof(UpdateSchemaBonusProviderAttribute)));
            UpdateSchemaProviderRegister.GetAvailableProviders(availableProviders, additionalAssemblies);
            Type result;
            string xpoProviderTypeString;
            Assert.That(UpdateSchemaProviderHelper.TryGetXpoProvider(connectionString, out xpoProviderTypeString), Is.True);
            Assert.That(availableProviders.TryGetValue(xpoProviderTypeString.ToUpper(), out result), Is.True);
            return result;
        }

        internal static void XpoCreateSchema(Assembly[] assemblies, string connectionString)
        {
            using (IDataLayer dataLayer = XpoDefault.GetDataLayer(connectionString, AutoCreateOption.DatabaseAndSchema))
            {
                using (Session session = new Session(dataLayer))
                {
                    session.UpdateSchema(assemblies);
                    session.CreateObjectTypeRecords(assemblies);
                    session.Disconnect();
                }
                dataLayer.Connection.Close();
            }
        }

        internal static void XpoCreateSchema(Type[] types, string connectionString)
        {
            using (IDataLayer dataLayer = XpoDefault.GetDataLayer(connectionString, AutoCreateOption.DatabaseAndSchema))
            {
                using (Session session = new Session(dataLayer))
                {
                    session.UpdateSchema(types);
                    session.CreateObjectTypeRecords(types);
                    session.Disconnect();
                }
                dataLayer.Connection.Close();
            }
        }
    }
}
