#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace Test.Xpo.UpdateSchema
{
    using DevExpress.Xpo.DB;
    using DevExpress.Xpo.Exceptions;
    using DevExpressContrib.Xpo.UpdateSchema;
    //using DevLynx.Framework.Core.Xpo;
    using NUnit.Framework;
    using NUnit.Framework.SyntaxHelpers;

    [TestFixture]
    public class TestProviderHelper
    {

        [Test]
        [ExpectedException(typeof(CannotFindAppropriateConnectionProviderException))]
        public void TestInvalidConnectionString()
        {
            // this connection string is invalid for any supported database
            string connectionString = "Data Source=Invalid;Provider=Invalid";
            string xpoProviderName;
            UpdateSchemaProviderHelper.TryGetXpoProvider(connectionString, out xpoProviderName);
        }

        [Test]
        public void TestTryGetXpoProvider()
        {
            // .NET built in providers
            TestFromGeneratedConnectionStringDotNetBuiltIn(MSSqlConnectionProvider.GetConnectionString("MyServer", "MyDatabase"), MSSqlConnectionProvider.XpoProviderTypeString);
            TestFromGeneratedConnectionStringDotNetBuiltIn(AccessConnectionProvider.GetConnectionString(@"C:\Temp\Access.mdb"), AccessConnectionProvider.XpoProviderTypeString);

            // Bonus providers
#if (ASA)
            TestFromGeneratedConnectionString(AsaConnectionProvider.GetConnectionString(@"C:\Temp\Asa.db", "dba", "sql"), AsaConnectionProvider.XpoProviderTypeString);
#endif // (ASA)
#if (VistaDB3)
            TestFromGeneratedConnectionString(VistaDB3ConnectionProvider.GetConnectionString(@"C:\Temp\VistaDB3.vdb3"), VistaDB3ConnectionProvider.XpoProviderTypeString);
#endif // (VistaDB3)
        }

        private static void TestFromGeneratedConnectionString(string connectionString, string expectedXpoProviderName)
        {
            string xpoProviderName;
            // The constructed connection string will include an XPO provider name
            bool result = UpdateSchemaProviderHelper.TryGetXpoProvider(connectionString, out xpoProviderName);
            Assert.That(result, Is.True);
            Assert.That(xpoProviderName, Is.EqualTo(expectedXpoProviderName));
        }

        private void TestFromGeneratedConnectionStringDotNetBuiltIn(string connectionString, string expectedXpoProviderName)
        {
            TestFromGeneratedConnectionString(connectionString, expectedXpoProviderName);

            // Now remove the XPO provider parameter. For the .NET built in providers
            // this should still work.
            string xpoProviderName;
            connectionString = UpdateSchemaProviderHelper.RemoveXpoProviderTypeParameter(connectionString);
            bool result = UpdateSchemaProviderHelper.TryGetXpoProvider(connectionString, out xpoProviderName);
            Assert.That(result, Is.True);
            Assert.That(xpoProviderName, Is.EqualTo(expectedXpoProviderName));
        }
    }
}
