#region Copyright  2008-2009, DevExpressContrib (MIT License)
// This software is licensed under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#endregion

namespace Test.XtraGrid.DxValidateColumnProvider
{
    using System;
    using System.Data;
    using System.Reflection;
    using DevExpress.Utils;
    using DevExpress.Xpo;
    using DevExpress.Xpo.DB;
    using DevExpress.XtraEditors;
    using DevExpress.XtraEditors.DXErrorProvider;
    using DevExpressContrib.XtraGrid.DxValidateColumnProvider;
    using Test.XtraGrid.DxValidateColumnProvider.Properties;

    public partial class TestXtraForm : XtraForm
    {

        private IDataLayer dataLayer;
        private Session dataSession;
        private DataSet dataset;
        private DxValidateColumnProvider validateColumn;


        public TestXtraForm()
        {
            InitializeComponent();
            dataset = new DataSet();
            CreateData();
            SetValidationRules();
        }


        private void barButtonItem2_ItemClick(object sender, DevExpress.XtraBars.ItemClickEventArgs e)
        {
            if (!validateColumn.HasColumnErrors(grid.MainView))
                if (grid.MainView == gridView)
                    grid.MainView = layoutView;
                else
                    grid.MainView = gridView;
        }

        private void barButtonItem3_ItemClick(object sender, DevExpress.XtraBars.ItemClickEventArgs e)
        {
            validateColumn.ClearColumnErrors();
        }

        private void barButtonItem4_ItemClick(object sender, DevExpress.XtraBars.ItemClickEventArgs e)
        {
            validateColumn.SetColumnError("Warning", ErrorType.Warning);
        }

        private void CreateData()
        {
            dataLayer = new SimpleDataLayer(new InMemoryDataStore(new DataSet(), AutoCreateOption.DatabaseAndSchema));
            using (Session session = new Session(dataLayer))
            {
                session.UpdateSchema(Assembly.GetExecutingAssembly());
                session.CreateObjectTypeRecords(Assembly.GetExecutingAssembly());
            }

            dataSession = new Session(dataLayer);
            XPCollection<Person> people = new XPCollection<Person>(dataSession);
            people.DisplayableProperties = Person.DisplayableProperties;

            for (int i = 0; i < 10; i++)
            {
                Person person = new Person(dataSession);
                person.Age = i + 20;
                person.Name = String.Format("Person: {0}", person.Age);
                person.Code = String.Format("Code: {0}", person.Age);
                person.Save();
                people.Add(person);
            }

            grid.DataSource = people;
            layoutView.PopulateColumns(people);
            gridView.PopulateColumns(people);
            gridView.Columns.ColumnByFieldName("Age").AppearanceHeader.TextOptions.HAlignment = HorzAlignment.Far;
            gridView.BestFitColumns();
        }

        private void SetValidationRules()
        {
            validateColumn = new DxValidateColumnProvider(true, gridView);
            validateColumn.AddView(layoutView);
            validateColumn.RowValidator = new ValidateRow();
            validateColumn.SetValidationRule("Name", new NotBlankTrimmedColumnValidationRule());
            int minAge = 18;
            validateColumn.SetValidationRule("Age", new ConditionColumnValidator(String.Format("Age must be greater than {0}.", minAge), ConditionOperator.Greater, minAge), gridView, layoutView);
            validateColumn.SetValidationRule("Code", new CompareAgainstColumnValueValidator("Name", CompareControlOperator.NotEquals, "Code must be different then Name."));
        }
    }

    public class ValidateRow : ColumnValidationRule
    {

        public ValidateRow() : base() { }


        public override bool Validate(object value)
        {
            ErrorText = String.Empty;
            object codeObj = GetRowCellValue("Code");
            string code = codeObj.ToString();
            object ageObj = GetRowCellValue("Age");
            int age = Convert.ToInt32(ageObj);
            bool result = code.EndsWith(" " + age.ToString());
            if (!result)
            {
                ErrorText = "'Code' must end with 'Age'";
                SetColumnError(ColumnByFieldName("Code"), ErrorText);
            }
            return result;
        }
    }

    public class NotBlankTrimmedColumnValidationRule : ColumnValidationRule
    {

        public NotBlankTrimmedColumnValidationRule() : base() { }


        public override bool Validate(object value)
        {
            if (value != null && value is string)
                value = (value as string).Trim();
            bool result = ValidationHelper.Validate(value, ConditionOperator.IsNotBlank, value, null, null);
            if (!result)
                ErrorText = Resources.ValueCannotBeBlank;
            return result;
        }
    }
}
